- pars
vector of parameters of length 1 or more. The first component contains the coefficient-value of the intercept, the next component(s) the ARCH-coefficient(s), and so on.
- arch
NULL or integer vector with the lags of the ARCH-terms to include. Works in the same way as the arch argument in the garchx function
- garch
NULL or integer vector with the lags of the GARCH-terms. Works in the same way as the garch argument in the garchx function
- asym
NULL or integer vector with the lags of the asymmetry terms to include. Works in the same way as the asym argument in the garchx function
- xreg
NULL, or a vector or matrix with the covariates of the model. Works in the same way as the xreg argument in the garchx function
- vcov.type
character that determines the type of coefficient-covariance
- innovations
NULL or a vector with the standardised innovations to use. If NULL, then the innovations are standard normal
- Eeta4
numeric, the fourth moment of the innovations. If NULL, then the value is estimated internally. Note: The value of Eeta4 is only used if vcov.type = "ordinary", otherwise it is ignored
- n
integer, the number of observations to use in the simulations
- objective.fun
integer equal to 1 or 0 that determines the type of objective function to use, see the code of garchxObjective
- seed
NULL or an integer that sets the seed (the value is passed on to set.seed. Useful for reproducibility